
- [X] examples: nats-pub, nats-sub
- [X] tests
- [X] request pattern
- [X] inboxes
- [X] ping/pong interval
- [X] correct verbose and pedantic handling
- [X] cluster
- [X] authorization
- [X] reconnection and state
- [X] readings deadline, flush timeout
- [X] more thorough test split buffer scenarios
- [X] benchmarks
- [X] error, close, disconnected callbacks,
- [X] pending data buffering on reconnect
- [X] client connection stats
- [X] integration tests with server
- [X] follow size of max payload
- [X] closed state
- [ ] confirm performance issues handling on larger messages
- [ ] TLS
- [X] Travis builds
- [ ] Release on PyPI
